@@ -3,11 +3,17 @@
 This environment will be updated without concern for backwards incompatible changes to
 template rendering behavior.
 """
+
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
+from typing import Type
+
 from ..environment import Environment as DefaultEnvironment
 from ..template import FutureBoundTemplate
-from .filters import split
-from .tags import LaxIfTag
-from .tags import LaxUnlessTag
+
+if TYPE_CHECKING:
+    from ..template import BoundTemplate
 
 
 class Environment(DefaultEnvironment):
@@ -21,11 +27,4 @@ class Environment(DefaultEnvironment):
     See https://jg-rp.github.io/liquid/known_issues
     """
 
-    template_class = FutureBoundTemplate
-
-    def setup_tags_and_filters(self) -> None:
-        """Add future tags and filters to this environment."""
-        super().setup_tags_and_filters()
-        self.add_filter("split", split)
-        self.add_tag(LaxIfTag)
-        self.add_tag(LaxUnlessTag)
+    template_class: Type[BoundTemplate] = FutureBoundTemplate
